@@ -1,6 +1,5 @@
 """Collection of useful actions to define arguments."""
 
-import inspect
 import os
 import re
 import sys
@@ -8,17 +7,16 @@ import warnings
 from argparse import Action, SUPPRESS, _HelpAction, _SubParsersAction
 from contextlib import contextmanager
 from contextvars import ContextVar
-from typing import Any, Callable, Dict, List, Optional, Tuple, Type, Union
+from typing import Any, Dict, List, Optional, Tuple, Type, Union
 
 from .loaders_dumpers import get_loader_exceptions, load_value
-from .namespace import Namespace, split_key, split_key_leaf, split_key_root
+from .namespace import Namespace, split_key, split_key_root
 from .optionals import FilesCompleterMethod, get_config_read_mode
-from .type_checking import ArgumentParser, _ArgumentGroup
+from .type_checking import ArgumentParser
 from .typing import path_type
 from .util import (
     change_to_path_dir,
     default_config_option_help,
-    DirectedGraph,
     import_object,
     indent_text,
     is_subclass,
@@ -118,44 +116,6 @@ def _find_parent_action(
     return _find_parent_action_and_subcommand(parser, key, exclude=exclude)[0]
 
 
-def _find_parent_actions(
-    parser: 'ArgumentParser',
-    key: str,
-    exclude: Optional[Union[Type[Action], Tuple[Type[Action], ...]]] = None,
-) -> Optional[List[Action]]:
-    found: List[Action]
-    action = _find_parent_action(parser, key, exclude=exclude)
-    if action is not None:
-        found = [action]
-    else:
-        actions = filter_default_actions(parser._actions)
-        if exclude is not None:
-            actions = [a for a in actions if not isinstance(a, exclude)]
-        parts = split_key(key)
-        for n in reversed(range(len(parts))):
-            prefix = '.'.join(parts[:n+1])+'.'
-            found = [a for a in actions if a.dest.startswith(prefix)]
-            if found != []:
-                break
-    return None if found == [] else found
-
-
-def _find_subclass_action_or_class_group(
-    parser: 'ArgumentParser',
-    key: str,
-    exclude: Optional[Union[Type[Action], Tuple[Type[Action], ...]]] = None,
-) -> Optional[Union[Action, '_ArgumentGroup']]:
-    from .typehints import ActionTypeHint
-    action = _find_parent_action(parser, key, exclude=exclude)
-    if ActionTypeHint.is_subclass_typehint(action):
-        return action
-    key_set = {key, split_key_leaf(key)[0]}
-    for group in parser._action_groups:
-        if getattr(group, 'dest', None) in key_set and hasattr(group, 'instantiate_class'):
-            return group
-    return None
-
-
 def _is_action_value_list(action: Action) -> bool:
     """Checks whether an action produces a list value.
 
@@ -411,238 +371,6 @@ class _ActionHelpClassPath(Action):
         return args[num+1:]
 
 
-class _ActionLink(Action):
-
-    def __init__(
-        self,
-        parser,
-        source: Union[str, Tuple[str, ...]],
-        target: str,
-        compute_fn: Optional[Callable] = None,
-        apply_on: str = 'parse',
-    ):
-        self.parser = parser
-
-        # Set and check apply_on
-        self.apply_on = apply_on
-        if apply_on not in {'parse', 'instantiate'}:
-            raise ValueError("apply_on must be 'parse' or 'instantiate'.")
-
-        # Set and check compute function
-        self.compute_fn = compute_fn
-        if compute_fn is None and not isinstance(source, str):
-            raise ValueError('Multiple source keys requires a compute function.')
-
-        # Set and check source actions or group
-        exclude = (_ActionLink, _ActionConfigLoad, _ActionSubCommands, ActionConfigFile)
-        source = (source,) if isinstance(source, str) else source
-        if apply_on == 'instantiate':
-            if len(source) != 1:
-                raise ValueError('Links applied on instantiation only supported for a single source.')
-            self.source = [(source[0], _find_subclass_action_or_class_group(parser, source[0], exclude=exclude))]
-            if self.source[0][1] is None:
-                raise ValueError('Links applied on instantiation require source to be a subclass action or a class group.')
-            if '.' in self.source[0][1].dest:  # type: ignore
-                raise ValueError('Links applied on instantiation only supported for first level objects.')
-            if source[0] == self.source[0][1].dest and compute_fn is None:
-                raise ValueError('Links applied on instantiation with object as source requires a compute function.')
-        else:
-            self.source = [(s, _find_parent_actions(parser, s, exclude=exclude)) for s in source]  # type: ignore
-
-        # Set and check target action
-        self.target = (target, _find_parent_action(parser, target, exclude=exclude))
-        for key, action in self.source + [self.target]:
-            if action is None:
-                raise ValueError(f'No action for key "{key}".')
-        assert self.target[1] is not None
-
-        from .typehints import ActionTypeHint
-        is_target_subclass = ActionTypeHint.is_subclass_typehint(self.target[1])
-        valid_target_subclass = is_target_subclass and target.startswith(self.target[1].dest+'.init_args.')
-        valid_target_leaf = self.target[1].dest == target and not is_target_subclass
-        if not (valid_target_leaf or valid_target_subclass):
-            raise ValueError(f'Target key "{target}" must be for an individual argument.')
-
-        # Replace target action with link action
-        if not is_target_subclass:
-            for key in self.target[1].option_strings:
-                parser._option_string_actions[key] = self
-            parser._actions[parser._actions.index(self.target[1])] = self
-            for group in parser._action_groups:
-                if self.target[1] in group._group_actions:
-                    group._group_actions.remove(self.target[1])
-
-        # Remove target from required
-        if target in parser.required_args:
-            parser.required_args.remove(target)
-        if is_target_subclass:
-            sub_add_kwargs = getattr(self.target[1], 'sub_add_kwargs', {})
-            if 'linked_targets' not in sub_add_kwargs:
-                sub_add_kwargs['linked_targets'] = set()
-            subtarget = target.split('.init_args.', 1)[1]
-            sub_add_kwargs['linked_targets'].add(subtarget)
-
-        # Add link action to group to show in help
-        if not hasattr(parser, '_links_group'):
-            parser._links_group = parser.add_argument_group('Linked arguments')
-        parser._links_group._group_actions.append(self)
-
-        # Check instantiation link does not create cycle
-        if apply_on == 'instantiate':
-            try:
-                self.instantiation_order(parser)
-            except ValueError as ex:
-                raise ValueError(f'Invalid link {source[0]} --> {target}: {ex}') from ex
-
-        # Initialize link action
-        if compute_fn is None:
-            link_str = source[0]
-        else:
-            link_str = getattr(compute_fn, '__name__', str(compute_fn))+'('+', '.join(source)+')'
-        link_str += ' --> ' + target
-
-        help_str: Optional[str]
-        if is_target_subclass:
-            type_attr = None
-            help_str = f'Use --{self.target[1].dest}.help CLASS_PATH for details.'
-        else:
-            type_attr = getattr(self.target[1], '_typehint', self.target[1].type)
-            help_str = self.target[1].help
-
-        super().__init__(
-            [link_str],
-            dest=target,
-            default=SUPPRESS,
-            metavar=f'[applied on {self.apply_on}]',
-            type=type_attr,
-            help=help_str,
-        )
-
-    def __call__(self, *args, **kwargs):
-        source = ', '.join(s[0] for s in self.source)
-        raise TypeError(f'Linked "{self.target[0]}" must be given via "{source}".')
-
-    def _check_type(self, value, cfg=None):
-        return self.parser._check_value_key(self.target[1], value, self.target[0], cfg)
-
-    @staticmethod
-    def apply_parsing_links(parser: 'ArgumentParser', cfg: Namespace) -> None:
-        subcommand, subparser = _ActionSubCommands.get_subcommand(parser, cfg, fail_no_subcommand=False)
-        if subcommand:
-            _ActionLink.apply_parsing_links(subparser, cfg[subcommand])  # type: ignore
-        if not hasattr(parser, '_links_group'):
-            return
-        for action in parser._links_group._group_actions:  # type: ignore
-            if action.apply_on != 'parse':
-                continue
-            from .typehints import ActionTypeHint
-            try:
-                args = []
-                for source_key, source_action in action.source:
-                    if ActionTypeHint.is_subclass_typehint(source_action[0]) and source_key not in cfg:
-                        parser.logger.debug(f'Link {action.option_strings[0]} ignored since source {source_action[0]._typehint} does not have that parameter.')
-                    args.append(cfg[source_key])
-            except KeyError:
-                continue
-            if action.compute_fn is None:
-                value = args[0]
-                # Automatic namespace to dict based on link target type hint
-                target_key, target_action = action.target
-                if isinstance(value, Namespace) and isinstance(target_action, ActionTypeHint):
-                    same_key = target_key == target_action.dest
-                    if (same_key and target_action.is_mapping_typehint(target_action._typehint)) or \
-                       target_action.is_init_arg_mapping_typehint(target_key, cfg):
-                        value = value.as_dict()
-            else:
-                # Automatic namespace to dict based on compute_fn param type hint
-                params = list(inspect.signature(action.compute_fn).parameters.values())
-                for n, param in enumerate(params):
-                    if n < len(args) and isinstance(args[n], Namespace) and ActionTypeHint.is_mapping_typehint(param.annotation):
-                        args[n] = args[n].as_dict()
-                # Compute value
-                value = action.compute_fn(*args)
-            _ActionLink.set_target_value(action, value, cfg, parser.logger)
-
-    @staticmethod
-    def apply_instantiation_links(parser, cfg, source):
-        if not hasattr(parser, '_links_group'):
-            return
-        for action in parser._links_group._group_actions:
-            source_key, source_action = action.source[0]
-            if action.apply_on != 'instantiate' or source != source_action.dest:
-                continue
-            source_object = cfg[source]
-            if source_key == source_action.dest:
-                value = action.compute_fn(source_object)
-            else:
-                attr = split_key_leaf(source_key)[1]
-                from .typehints import ActionTypeHint
-                if ActionTypeHint.is_subclass_typehint(source_action) and not hasattr(source_object, attr):
-                    parser.logger.debug(f'Link {action.option_strings[0]} ignored since source {source_action._typehint} does not have that parameter.')
-                    continue
-                value = getattr(source_object, attr)
-                if action.compute_fn is not None:
-                    value = action.compute_fn(value)
-            _ActionLink.set_target_value(action, value, cfg, parser.logger)
-
-    @staticmethod
-    def set_target_value(action: '_ActionLink', value: Any, cfg: Namespace, logger) -> None:
-        target_key, target_action = action.target
-        from .typehints import ActionTypeHint
-        if ActionTypeHint.is_subclass_typehint(target_action) and target_key not in cfg:
-            logger.debug(f'Link {action.option_strings[0]} ignored since target {target_action._typehint} does not have that parameter.')  # type: ignore
-            return
-        cfg[target_key] = value
-
-    @staticmethod
-    def instantiation_order(parser):
-        if hasattr(parser, '_links_group'):
-            actions = [a for a in parser._links_group._group_actions if a.apply_on == 'instantiate']
-            if len(actions) > 0:
-                graph = DirectedGraph()
-                for action in actions:
-                    source = action.source[0][1].dest
-                    target = re.sub(r'\.init_args$', '', split_key_leaf(action.target[0])[0])
-                    graph.add_edge(source, target)
-                return graph.get_topological_order()
-        return []
-
-    @staticmethod
-    def reorder(order, components):
-        ordered = []
-        for key in order:
-            after = []
-            for component in components:
-                if key == component.dest or component.dest.startswith(key+'.'):
-                    ordered.append(component)
-                else:
-                    after.append(component)
-            components = after
-        return ordered + components
-
-    @staticmethod
-    def strip_link_target_keys(parser, cfg):
-        def del_taget_key(target_key):
-            cfg.pop(target_key, None)
-            parent_key, _ = split_key_leaf(target_key)
-            if '.' in target_key and parent_key in cfg and not cfg[parent_key]:
-                del cfg[parent_key]
-
-        for action in [a for a in parser._actions if isinstance(a, _ActionLink)]:
-            del_taget_key(action.target[0])
-        from .typehints import ActionTypeHint
-        for action in [a for a in parser._actions if isinstance(a, ActionTypeHint) and hasattr(a, 'sub_add_kwargs')]:
-            for key in action.sub_add_kwargs.get('linked_targets', []):
-                del_taget_key(action.dest+'.init_args.'+key)
-
-        with _ActionSubCommands.not_single_subcommand():
-            subcommands, subparsers = _ActionSubCommands.get_subcommands(parser, cfg)
-        if subcommands is not None:
-            for num, subcommand in enumerate(subcommands):
-                if subcommand in cfg:
-                    _ActionLink.strip_link_target_keys(subparsers[num], cfg[subcommand])
-
-
 class ActionYesNo(Action):
     """Paired options --[yes_prefix]opt, --[no_prefix]opt to set True or False respectively."""
 
@@ -817,7 +545,7 @@ def parent_parsers_context(key, parser):
 class _ActionSubCommands(_SubParsersAction):
     """Extension of argparse._SubParsersAction to modify subcommands functionality."""
 
-    _env_prefix: Optional[str] = None
+    _env_prefix: Union[bool, str] = True
 
 
     def add_parser(self, name, **kwargs):
