@@ -13,7 +13,7 @@ def run_tests():
     filter_action = 'default'
     warnings.simplefilter(filter_action)
     os.environ['PYTHONWARNINGS'] = filter_action
-    tests = unittest.defaultTestLoader.discover(testing_package, pattern='*_tests.py')
+    tests = unittest.defaultTestLoader.discover(testing_package)
     if not unittest.TextTestRunner(verbosity=2).run(tests).wasSuccessful():
         sys.exit(True)
 
@@ -21,7 +21,7 @@ def run_tests():
 def run_test_coverage():
     try:
         import coverage
-    except:
+    except ImportError:
         print('error: coverage package not found, run_test_coverage requires it.')
         sys.exit(True)
     package_source = os.path.dirname(__file__.replace('_tests', ''))
